@echo off
rem -------------------------------------------------------------------------------
rem Configure WebSphere MQ permissions Script
rem
rem Arguments: -g queueManagerName RITEntity puttingApplicationEntity mirrorQueuePrefix
rem
rem -g
rem          Group mode. Set permissions for groups instead of users. 
rem          Defaults to setting permissions for users. (Optional)
rem queueManagerName
rem          The name of the local queue manager to configure permissions for.
rem RITEntity
rem          The user ID configured in the physical resources in
rem          Rational Integration Tester or, the name of a group that the user belongs
rem          to.
rem puttingApplicationEntity
rem          The user ID used by the existing application putting messages onto MQ queues or,
rem          the name of a group that the user belongs to.
rem mirrorQueuePrefix
rem          The prefix for mirror queues specified in the recording tab of the physical transport.
rem          Defaults to blank. (Optional)
rem -------------------------------------------------------------------------------

setlocal

rem ---- Check to see whether we should apply permissions for users or groups
rem      Defaults to users ----
SET entityType=-p

if "%1"=="-g" (
    SET entityType=-g
    SHIFT
)

rem ---- Check to see if a mirror queue prefix has been specified ----
SET mirrorPrefix=

if "x%4x" NEQ "xx" (
	SET mirrorPrefix=%4.
	SHIFT /4
)

if "x%3x" == "xx" goto PrintUsage
if "x%4x" NEQ "xx" goto PrintUsage

rem Dump all existing queue manager authorities to file prior to running the setmqaut commands
dmpmqaut -m %1 > preExitRecordingAuthorityBackup.aut 2>&1

rem ---- Set permissions to enable access for the MQ user configured in RIT ----
setmqaut -m %1 -t qmgr %entityType% "%2" +connect +inq +dsp
setmqaut -m %1 -t q -n SYSTEM.DEFAULT.MODEL.QUEUE %entityType% "%2" +get +dsp
setmqaut -m %1 -t q -n SYSTEM.ADMIN.COMMAND.QUEUE %entityType% "%2" +inq +put
setmqaut -m %1 -n SYSTEM.DEFAULT.NAMELIST -t namelist %entityType% "%2" +dsp
setmqaut -m %1 -n "**" -t namelist %entityType% "%2" +crt
setmqaut -m %1 -n "com.greenhat.intercept*" -t namelist %entityType% "%2" +dsp +chg

rem ---- Set permissions to enable access for the MQ user used by the existing application ----
setmqaut -m %1 -t qmgr %entityType% "%3" +connect +inq +setall
setmqaut -m %1 -n "com.greenhat.intercept*" -t namelist %entityType% "%3" +inq
setmqaut -m %1 -n "AMQ.%mirrorPrefix%**" -t q %entityType% "%3" +put +setall

goto End

:PrintUsage
echo arguments: [-g] queueManagerName RITEntity puttingApplicationEntity [mirrorQueuePrefix]
echo -g
echo    Group mode. Set permissions for groups instead of users. Defaults to setting permissions for users. (Optional)
echo.
echo queueManagerName
echo    The name of the local queue manager to configure permissions for.
echo.
echo RITEntity
echo    The user ID configured in the physical resource in Rational Integration Tester or, the name of a group that the user belongs to.
echo.
echo puttingApplicationEntity
echo    The user ID used by the existing application putting messages onto MQ queues or, the name of a group that the user belongs to.
echo.
echo mirrorQueuePrefix
echo    The prefix for mirror queues specified in the recording tab of the physical transport. Defaults to blank. (Optional)
:End

endlocal